@@ -60,16 +60,13 @@ class DataFrameSummary(object):
             return self.df[column].values
 
         raise KeyError(column)
-    @classmethod
-    def _get_pairplot(self,continuous=[],categorical=[]):
-        print("Hello!",self.df)
-        if(self.df==None):
-            return "Send the Data Please"
+
+    def _get_pairplot(self):
         for i in self.df.columns:
             if(self.df[i].nunique/data.shape[0])*100>20:
-               continuous.append(i)
+               self.continuous.append(i)
             else:
-               categorical.append(i)
+               self.categorical.append(i)
         cn=self.df.drop(columns=categorical,axis=1)
         return sn.pairplot(cn,corner=True,kind="scatter")
         
